      SUBROUTINE TILES(FIELDA,NLONA,NLATA,INDII,INDJJ,
     1                 NLONO,NLATO,BETAO,AFIELD)
C
C     * APR 04/02 - B. MIVILLE - REVISED FOR NEW DATA DESCRIPTION FORMAT
C     * JUN 08/01 - B. MIVILLE
C
C     * GIVE THE SAME VALUE OF THE ATMOSPHERE POINT TO THE UNDERLYING 
C     * OCEAN POINTS
C
C     * INPUT PARAMETERS...
C 
C     * FIELDA = ATMOSPHERE FIELD
C     * NLONA  = NUMBER OF ATMOSPHERE LONGITUDES INCLUDING CYCLIC
C     * NLATA  = NUMBER OF ATMOSPHERE LATITUDES 
C     * INDII  = INDEX THE OCEAN I POINT TO ATMOSPHERE II POINT FOR 
C     *          ADJUSTMENT
C     * INDJJ  = INDEX THE OCEAN J POINT TO ATMOSPHERE JJ POINT FOR 
C     *          ADJUSTMENT
C     * AFIELD = OCEAN FIELD
C     * NLONO  = NUMBER OF OCEAN LONGITUDES INCLUDING CYCLIC
C     * NLATO  = NUMBER OF OCEAN LATITUDES
C     * BETAO  = HEAVISIDE FUNCTION FOR OCEAN GRID CELL
C
C     * OUTPUT PARAMETERS...
C
C     * AFIELD = TILED OCEAN FIELD
C
C-----------------------------------------------------------------------
C
      IMPLICIT REAL (A-H,O-Z),
     +INTEGER (I-N)
      INTEGER NLONA,NLATA,NLONO,NLATO
      INTEGER INDII(NLONO,NLATO),INDJJ(NLONO,NLATO)
      REAL AFIELD(NLONO,NLATO),FIELDA(NLONA,NLATA)
      REAL BETAO(NLONO,NLATO)
C-----------------------------------------------------------------------
C
      DO 710 J=1,NLATO
         DO 700 I=1,NLONO-1
            II=INDII(I,J)
            JJ=INDJJ(I,J)
            AFIELD(I,J)=BETAO(I,J)*FIELDA(II,JJ)
 700     CONTINUE
         AFIELD(NLONO,J)=AFIELD(1,J)
 710  CONTINUE
C
      RETURN
      END
